==> partitionmanager-3.0.0.tar.xz: partitionmanager-3.0.0/src/config/filesystemcolorspagewidget.h <==
/*************************************************************************
 *  Copyright (C) 2010 by Volker Lanz <vl@fidra.de>                      *
 *                                                                       *
 *  This program is free software; you can redistribute it and/or        *
 *  modify it under the terms of the GNU General Public License as       *
 *  published by the Free Software Foundation; either version 3 of       *
 *  the License, or (at your option) any later version.                  *
 *                                                                       *
 *  This program is distributed in the hope that it will be useful,      *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 *  GNU General Public License for more details.                         *
 *                                                                       *
 *  You should have received a copy of the GNU General Public License    *
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
 *************************************************************************/

#if !defined(FILESYSTEMCOLORSPAGEWIDGET__H)

#define FILESYSTEMCOLORSPAGEWIDGET__H

#include "ui_configurepagefilesystemcolors.h"

#include <QWidget>

class FileSystemColorsPageWidget : public QWidget, public Ui::ConfigurePageFileSystemColors
{
public:
    FileSystemColorsPageWidget(QWidget* parent);
};

#endif

==> partitionmanager-3.3.1.tar.xz: partitionmanager-3.3.1/src/config/filesystemcolorspagewidget.h <==
/*************************************************************************
 *  Copyright (C) 2010 by Volker Lanz <vl@fidra.de>                      *
 *                                                                       *
 *  This program is free software; you can redistribute it and/or        *
 *  modify it under the terms of the GNU General Public License as       *
 *  published by the Free Software Foundation; either version 3 of       *
 *  the License, or (at your option) any later version.                  *
 *                                                                       *
 *  This program is distributed in the hope that it will be useful,      *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 *  GNU General Public License for more details.                         *
 *                                                                       *
 *  You should have received a copy of the GNU General Public License    *
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
 *************************************************************************/

#if !defined(FILESYSTEMCOLORSPAGEWIDGET_H)

#define FILESYSTEMCOLORSPAGEWIDGET_H

#include "ui_configurepagefilesystemcolors.h"

#include <QWidget>

class FileSystemColorsPageWidget : public QWidget, public Ui::ConfigurePageFileSystemColors
{
public:
    FileSystemColorsPageWidget(QWidget* parent);
};

#endif
